# Xsuite 


[![Daily test (self-hosted, CUDA)](https://github.com/xsuite/xsuite/actions/workflows/cron_test_gpu_cuda.yaml/badge.svg)](https://github.com/xsuite/xsuite/actions/workflows/cron_test_gpu_cuda.yaml)
[![Daily test (self-hosted, OpenCL)](https://github.com/xsuite/xsuite/actions/workflows/cron_test_gpu_cl.yaml/badge.svg)](https://github.com/xsuite/xsuite/actions/workflows/cron_test_gpu_cl.yaml)
[![Daily test (self-hosted, CPU)](https://github.com/xsuite/xsuite/actions/workflows/cron_test_sh_cpu.yaml/badge.svg)](https://github.com/xsuite/xsuite/actions/workflows/cron_test_sh_cpu.yaml)

Suite of python packages for multiparticle simulations for particle accelerators.

Documentation is on: https://xsuite.readthedocs.io/en/latest/.
